import 'package:workouttest_util/model/cache.dart';
import 'package:workouttest_util/model/customer_exercise_device.dart';
import 'package:workouttest_util/model/exercise_device.dart';
import 'package:workouttest_util/model/model_change.dart';
import 'package:workouttest_util/service/customer_exercise_device_service.dart';

class CustomerExerciseDeviceRepository {
  List<CustomerExerciseDevice> _devices = [];

  List<CustomerExerciseDevice> getDevices() => _devices;

  void setDevices(List<CustomerExerciseDevice> devices) => _devices = devices;

  Future<List<CustomerExerciseDevice>?> getDBDevices() async {
    if (Cache().userLoggedIn != null) {
      final int customerId = Cache().userLoggedIn!.customerId!;
      _devices = await CustomerExerciseDeviceApi().getDevices(customerId);
    }
    return _devices;
  }

  Future<void> addDevice(ExerciseDevice device) async {
    CustomerExerciseDevice? found;

    for (var element in _devices) {
      if (element.exerciseDeviceId == device.exerciseDeviceId) {
        found = element;
      }
    }

    if (found == null) {
      int? customerId;
      if (Cache().userLoggedIn != null) {
        customerId = Cache().userLoggedIn!.customerId!;
      }
      CustomerExerciseDevice newDevice =
          CustomerExerciseDevice(customerId: customerId!, exerciseDeviceId: device.exerciseDeviceId, favourite: false);
      newDevice.change = ModelChange.add;
      CustomerExerciseDevice saved = await CustomerExerciseDeviceApi().addDevice(newDevice);
      _devices.add(saved);
      Cache().setCustomerDevices(_devices);
    }
  }

  Future<void> removeDevice(ExerciseDevice device) async {
    CustomerExerciseDevice? found;

    for (var element in _devices) {
      if (element.exerciseDeviceId == device.exerciseDeviceId) {
        found = element;
      }
    }

    if (found != null) {
      _devices.remove(found);
      //if (found.change != ModelChange.add) {
      await CustomerExerciseDeviceApi().removeDevice(found.customerExerciseDeviceId!);
      //}
      Cache().setCustomerDevices(_devices);
    }
  }

  bool hasDevice(int exerciseDeviceId) {
    bool found = false;

    for (var element in _devices) {
      if (element.exerciseDeviceId == exerciseDeviceId) {
        found = true;
      }
    }

    return found;
  }
}
